@@ -1,5 +1,5 @@
 /* ap.c --- AP functions
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -342,10 +342,6 @@ shishi_ap_set_tktoptionsasn1usage (Shishi_ap * ap,
   if (res != SHISHI_OK)
     return res;
 
-  /* XXX what is this? */
-  memmove (buf, buf + 2, buflen - 2);
-  buflen -= 2;
-
   res = shishi_ap_set_tktoptionsdata (ap, tkt, options, buf, buflen);
   if (res != SHISHI_OK)
     return res;
@@ -799,6 +795,13 @@ shishi_ap_req_build (Shishi_ap * ap)
   if (VERBOSE (ap->handle))
     printf ("Building AP-REQ...\n");
 
+  if (VERBOSEASN1 (ap->handle))
+    {
+      shishi_ticket_print (ap->handle, stdout, shishi_tkt_ticket (ap->tkt));
+      shishi_key_print (ap->handle, stdout, shishi_tkt_key (ap->tkt));
+    }
+
+
   res = shishi_apreq_set_ticket (ap->handle, ap->apreq,
 				 shishi_tkt_ticket (ap->tkt));
   if (res != SHISHI_OK)
