@@ -1,5 +1,5 @@
 /* crypto-des.c --- DES crypto functions.
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -118,8 +118,12 @@ raw_des_checksum1 (Shishi * handle, int algo,
       break;
     }
 
+  free (tmp);
+
   memcpy (out + blen, p, hlen);
 
+  free (p);
+
   *outlen = blen + hlen;
 
   return SHISHI_OK;
@@ -407,7 +411,7 @@ static char weak_des_keys[16][8] = {
   "\xFE\xE0\xFE\xE0\xFE\xF1\xFE\xF1"
 };
 
-static int
+static void
 des_key_correction (Shishi * handle, char key[8])
 {
   size_t i;
@@ -425,8 +429,6 @@ des_key_correction (Shishi * handle, char key[8])
 	key[7] ^= 0xF0;
 	break;
       }
-
-  return SHISHI_OK;
 }
 
 static int
@@ -592,9 +594,7 @@ des_string_to_key (Shishi * handle,
       printf ("tempkey = key_correction(add_parity_bits(tempstring));\n");
     }
 
-  res = des_key_correction (handle, tempkey);
-  if (res != SHISHI_OK)
-    return res;
+  des_key_correction (handle, tempkey);
 
   if (VERBOSECRYPTONOISE (handle))
     {
@@ -613,12 +613,11 @@ des_string_to_key (Shishi * handle,
   res = shishi_des_cbc_mac (handle, tempkey, tempkey, s, n_s, &p);
   if (res != SHISHI_OK)
     return res;
+  free (s);
   memcpy (tempkey, p, 8);
   free (p);
 
-  res = des_key_correction (handle, tempkey);
-  if (res != SHISHI_OK)
-    return res;
+  des_key_correction (handle, tempkey);
 
   if (VERBOSECRYPTO (handle))
     {
