@@ -432,13 +432,13 @@ shishi_kdcrep_get_ticket (Shishi * handle,
       if (res != SHISHI_OK)
 	goto error;
 
-      asprintf (&format, "ticket.sname.name-string.?%d", i);
+      format = xasprintf ("ticket.sname.name-string.?%d", i);
       res = shishi_asn1_read (handle, kdcrep, format, &buf, &buflen);
       free (format);
       if (res != SHISHI_OK)
 	goto error;
 
-      asprintf (&format, "sname.name-string.?%d", i);
+      format = xasprintf ("sname.name-string.?%d", i);
       res = shishi_asn1_write (handle, *ticket, format, buf, buflen);
       free (format);
       free (buf);
@@ -548,13 +548,13 @@ shishi_kdcrep_set_ticket (Shishi * handle, Shishi_asn1 kdcrep,
       if (res != SHISHI_OK)
 	return res;
 
-      asprintf (&format, "sname.name-string.?%d", i);
+      format = xasprintf ("sname.name-string.?%d", i);
       res = shishi_asn1_read (handle, ticket, format, &buf, &buflen);
       free (format);
       if (res != SHISHI_OK)
 	return res;
 
-      asprintf (&format, "ticket.sname.name-string.?%d", i);
+      format = xasprintf ("ticket.sname.name-string.?%d", i);
       res = shishi_asn1_write (handle, kdcrep, format, buf, buflen);
       free (format);
       free (buf);
