@@ -1070,6 +1070,45 @@ shishi_krberror_edata (Shishi * handle, Shishi_asn1 krberror,
   return shishi_asn1_read (handle, krberror, "e-data", edata, edatalen);
 }
 
+/**
+ * shishi_krberror_methoddata:
+ * @handle: shishi handle as allocated by shishi_init().
+ * @krberror: KRB-ERROR structure with error code.
+ * @methoddata: output ASN.1 METHOD-DATA.
+ *
+ * Extract METHOD-DATA ASN.1 object from the e-data field.  The e-data
+ * field will only contain a METHOD-DATA if the krberror error code is
+ * %SHISHI_KDC_ERR_PREAUTH_REQUIRED.
+ *
+ * Return value: Returns SHISHI_OK iff successful.
+ **/
+int
+shishi_krberror_methoddata (Shishi * handle, Shishi_asn1 krberror,
+			    Shishi_asn1 *methoddata)
+{
+  int rc;
+
+  *methoddata = NULL;
+
+  if (shishi_krberror_errorcode_fast (handle, krberror)
+      == SHISHI_KDC_ERR_PREAUTH_REQUIRED)
+    {
+      char *buf;
+      size_t len;
+
+      rc = shishi_krberror_edata (handle, krberror, &buf, &len);
+      if (rc != SHISHI_OK)
+	return rc;
+
+      *methoddata = shishi_der2asn1_methoddata (handle, buf, len);
+      free (buf);
+      if (!*methoddata)
+	return SHISHI_ASN1_ERROR;
+    }
+
+  return SHISHI_OK;
+}
+
 /**
  * shishi_krberror_set_edata:
  * @handle: shishi handle as allocated by shishi_init().
@@ -1142,9 +1181,12 @@ shishi_krberror_pretty_print (Shishi * handle, FILE * fh,
       fprintf (fh, "Generic error from server:\n");
 
       res = shishi_krberror_etext (handle, krberror, &buf, &len);
-      buf[len] = '\0';
       if (res == SHISHI_OK && len > 0)
-	fprintf (fh, "%s\n", buf);
+	{
+	  buf[len] = '\0';
+	  fprintf (fh, "%s\n", buf);
+	  free (buf);
+	}
     }
   else
     {
@@ -1156,6 +1198,47 @@ shishi_krberror_pretty_print (Shishi * handle, FILE * fh,
 	{
 	  buf[len] = '\0';
 	  fprintf (fh, "Additional error message from server:\n%s\n", buf);
+	  free (buf);
+	}
+
+      if (shishi_krberror_errorcode_fast (handle, krberror) ==
+	  SHISHI_KDC_ERR_PREAUTH_REQUIRED)
+	{
+	  Shishi_asn1 pas;
+	  size_t i, n;
+
+	  res = shishi_krberror_methoddata (handle, krberror, &pas);
+	  if (res != SHISHI_OK)
+	    return res;
+
+	  if (VERBOSEASN1 (handle))
+	    shishi_methoddata_print (handle, stdout, pas);
+
+	  res = shishi_asn1_number_of_elements (handle, pas, "", &n);
+	  if (res == SHISHI_OK)
+	    {
+	      fprintf (fh, "Types of PA-DATA in KRB-ERROR: ");
+
+	      for (i = 1; i <= n; i++)
+		{
+		  char *format = xasprintf ("?%d.padata-type", i);
+		  int32_t padatatype;
+
+		  if (i > 1)
+		    fprintf (fh, ", ");
+
+		  res = shishi_asn1_read_int32 (handle, pas, format,
+						&padatatype);
+		  if (res == SHISHI_OK)
+		    printf ("%d", padatatype);
+
+		  free (format);
+		}
+
+	      fprintf (fh, ".\n");
+	    }
+
+	  shishi_asn1_done (handle, pas);
 	}
     }
 
