@@ -152,16 +152,14 @@ shishi_tkts (Shishi * handle, Shishi_tkts ** tkts)
 void
 shishi_tkts_done (Shishi_tkts ** tkts)
 {
-  Shishi_tkts *tset;
-
   if (!tkts || !*tkts)
     return;
 
-  tset = *tkts;
+  if ((*tkts)->tkts)
+    free ((*tkts)->tkts);
+  free (*tkts);
 
-  if (tset->tkts)
-    free (tset->tkts);
-  free (tset);
+  *tkts = NULL;
 
   return;
 }
@@ -345,7 +343,7 @@ shishi_tkts_read (Shishi_tkts * tkts, FILE * fh)
       if (res != SHISHI_OK)
 	break;
 
-      if (VERBOSE (tkts->handle))
+      if (VERBOSEASN1 (tkts->handle))
 	{
 	  printf ("Read ticket for principal `':\n");
 	  shishi_kdcrep_print (tkts->handle, stdout, kdcrep);
@@ -958,8 +956,7 @@ recover_preauth_info (Shishi_tkts *tkts,
   size_t i, n;
   int rc;
 
-  if (VERBOSENOISE(tkts->handle))
-    printf ("Found INFO-ETYPE(2) pre-auth hints, trying to find etype...\n");
+  shishi_verbose (tkts->handle, "Found INFO-ETYPE(2) pre-auth hints");
 
   if (VERBOSEASN1(tkts->handle))
     {
@@ -971,8 +968,7 @@ recover_preauth_info (Shishi_tkts *tkts,
 
   if (lochint->preauthetype)
     {
-      if (VERBOSENOISE(tkts->handle))
-	printf ("Pre-auth data already specified...\n");
+      shishi_verbose (tkts->handle, "Pre-auth data already specified");
       return SHISHI_OK;
     }
 
@@ -992,8 +988,7 @@ recover_preauth_info (Shishi_tkts *tkts,
 	{
 	  size_t j;
 
-	  if (VERBOSENOISE(tkts->handle))
-	    printf ("Server has etype %d...\n", etype);
+	  shishi_verbose (tkts->handle, "Server has etype %d", etype);
 
 	  for (j = 0; j < tkts->handle->nclientkdcetypes; j++)
 	    {
@@ -1004,7 +999,7 @@ recover_preauth_info (Shishi_tkts *tkts,
 		      char *salt;
 		      size_t saltlen;
 
-		      printf ("New best etype %d...\n", etype);
+		      shishi_verbose (tkts->handle, "New best etype %d", etype);
 
 		      /* XXX mem leak. */
 
@@ -1038,8 +1033,8 @@ recover_preauth_info (Shishi_tkts *tkts,
     {
       lochint->preauthetype = tkts->handle->clientkdcetypes[foundpos];
 
-      if (VERBOSENOISE(tkts->handle))
-	printf ("Best pre-auth etype was %d...\n", lochint->preauthetype);
+      shishi_verbose (tkts->handle, "Best pre-auth etype was %d",
+		      lochint->preauthetype);
 
       *retry = true;
     }
@@ -1065,8 +1060,7 @@ recover_preauth (Shishi_tkts *tkts,
 
   *retry = false;
 
-  if (VERBOSE(tkts->handle))
-    printf ("Server requested pre-auth data, figuring out what to send...\n");
+  shishi_verbose (tkts->handle, "Server requests pre-auth data");
 
   rc = shishi_krberror_methoddata (tkts->handle, krberror, &pas);
   if (rc != SHISHI_OK)
@@ -1085,8 +1079,8 @@ recover_preauth (Shishi_tkts *tkts,
 	  free (format);
 	  if (rc == SHISHI_OK)
 	    {
-	      if (VERBOSENOISE(tkts->handle))
-		printf ("Looking at pa-type %d...\n", padatatype);
+	      shishi_verbose (tkts->handle, "Looking at pa-type %d",
+			      padatatype);
 
 	      switch (padatatype)
 		{
