@@ -125,26 +125,24 @@ kdc_send1 (struct listenspec *ls)
 static void
 kdc_send (struct listenspec *ls)
 {
-  if (ls->usetls)
-    syslog (LOG_DEBUG, "Sending %d bytes to %s socket %d via TLS",
+  if (ls->type == SOCK_DGRAM)
+    syslog (LOG_DEBUG, "Sending %d bytes to %s socket %d via UDP",
 	    ls->bufpos, ls->str, ls->sockfd);
-  else if (ls->type == SOCK_STREAM)
+  else
     {
-      uint32_t len = htonl (ls->bufpos) + 4;
-
-      syslog (LOG_DEBUG, "Sending %d bytes to %s socket %d via TCP",
-	      ls->bufpos, ls->str, ls->sockfd);
+      syslog (LOG_DEBUG, "Sending %d bytes to %s socket %d via %s",
+	      ls->bufpos, ls->str, ls->sockfd, ls->usetls ? "TLS" : "TCP");
 
       if (ls->bufpos + 4 >= sizeof (ls->buf))
 	ls->bufpos = sizeof (ls->buf) - 4;
 
       memmove (ls->buf + 4, ls->buf, ls->bufpos);
-      memcpy (ls->buf, &len, 4);
+      ls->buf[0] = (ls->bufpos >> 24) & 0xFF;
+      ls->buf[1] = (ls->bufpos >> 16) & 0xFF;
+      ls->buf[2] = (ls->bufpos >> 8) & 0xFF;
+      ls->buf[3] = ls->bufpos & 0xFF;
       ls->bufpos += 4;
     }
-  else
-    syslog (LOG_DEBUG, "Sending %d bytes to %s socket %d via UDP",
-	    ls->bufpos, ls->str, ls->sockfd);
 
   kdc_send1 (ls);
 
@@ -169,7 +167,9 @@ kdc_read (struct listenspec *ls)
   ls->addrlen = sizeof (ls->addr);
 #ifdef USE_STARTTLS
   if (ls->usetls)
-    read_bytes = gnutls_record_recv (ls->session, ls->buf, sizeof (ls->buf));
+    read_bytes = gnutls_record_recv (ls->session,
+				     ls->buf + ls->bufpos,
+				     sizeof (ls->buf) - ls->bufpos);
   else
 #endif
     read_bytes = recvfrom (ls->sockfd, ls->buf + ls->bufpos,
@@ -204,13 +204,23 @@ kdc_read (struct listenspec *ls)
   return 0;
 }
 
+#define C2I(buf) ((buf[3] & 0xFF) |		\
+		  ((buf[2] & 0xFF) << 8) |	\
+		  ((buf[1] & 0xFF) << 16) |	\
+		  ((buf[0] & 0xFF) << 24))
+
 /* Have we read an entire request? */
 static int
 kdc_ready (struct listenspec *ls)
 {
-  if ((ls->usetls || ls->type == SOCK_DGRAM) && ls->bufpos > 0)
+  int waitfor = ls->bufpos >= 4 ? C2I (ls->buf) : 4;
+
+  syslog (LOG_DEBUG, "Got %d bytes of %d bytes from %s on socket %d\n",
+	  ls->bufpos, waitfor + 4, ls->str, ls->sockfd);
+
+  if (ls->type == SOCK_DGRAM && ls->bufpos > 0)
     return 1;
-  else if (ls->bufpos > 4 && ntohl (*(int *) ls->buf) + 4 == ls->bufpos)
+  else if (ls->bufpos > 4 && waitfor + 4 == ls->bufpos)
     return 1;
 
   return 0;
@@ -226,7 +236,7 @@ kdc_process (struct listenspec *ls)
   syslog (LOG_DEBUG, "Processing %d from %s on socket %d",
 	  ls->bufpos, ls->str, ls->sockfd);
 
-  if (ls->usetls || ls->type == SOCK_DGRAM)
+  if (ls->type == SOCK_DGRAM)
     plen = process (ls->buf, ls->bufpos, &p);
   else
     plen = process (ls->buf + 4, ls->bufpos - 4, &p);
