@@ -214,7 +214,10 @@ main (int argc, char *argv[])
   if (debug)
     {
       shishi_cfg (handle, strdup ("verbose"));
+      shishi_cfg (handle, strdup ("verbose-noise"));
       shishi_cfg (handle, strdup ("verbose-asn1"));
+      shishi_cfg (handle, strdup ("verbose-crypto"));
+      shishi_cfg (handle, strdup ("verbose-crypto-noise"));
     }
 
   test (handle);
